@@ -1,6 +1,6 @@
 #!/bin/python
 
-from main import init
+from Simple_Process_REPL.main import init
 
 
 def main():
