@@ -606,7 +606,7 @@ def save_yaml_file(filename, dictionary):
 def load_yaml_file(filename):
     "load a dictionary from a yaml file"
     with open(filename) as f:
-        someyaml = yaml.load(f, Loader=yaml.FullLoader)
+        someyaml = yaml.load(f, Loader=yaml.SafeLoader)
     return someyaml
 
 
@@ -620,8 +620,18 @@ def load_defaults(pkgname=None, yamlname=None):
     return AS
 
 
+import pkg_resources
+
+# DATA_PATH = pkg_resources.resource_filename("<package name>", "data/")
+# DB_FILE = pkg_resources.resource_filename("<package name>", "data/sqlite.db")
+
+
 def load_pkg_config(pkgname, yamlname):
-    return yaml.load(pkgutil.get_data(pkgname, yamlname))
+    # return yaml.load(pkgutil.get_data(pkgname, yamlname), Loader=yaml.SafeLoader)
+    f = pkg_resources.resource_filename(pkgname, yamlname)
+    # print(f)
+    # print(load_yaml_file(f))
+    return load_yaml_file(f)
 
 
 def load_base_config():
